==> podwiki-0.8.0.tgz: podwiki-0.8.0/support/pwreset.pl <==
#!/usr/bin/perl

 #
 #   $Id: pwreset.pl,v 1.4 2004/05/20 21:33:03 zarahg Exp $
 #
 #   This  file  is  part of the  PodWiki  web-based authoring tool.
 #
 #   By  accessing  this software,  PodWiki,  you are  duly informed
 #   of and  agree to be  bound  by the  conditions  described below
 #   in this notice:
 #
 #   This software product, PodWiki,  is developed by  Thomas Linden
 #   and   copyrighted  (C) 2003-2004   by  Thomas Linden,  with all
 #   rights reserved.
 #
 #   There is  no charge for  PodWiki software. You can redistribute
 #   it and/or modify it under  the terms of the  GNU General Public
 #   License, which is incorporated by reference herein.
 #
 #   PodWiki is distributed WITHOUT ANY WARRANTY,IMPLIED OR EXPRESS,
 #   OF  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that
 #   the  use of it will not infringe on any third party's intellec-
 #   tual property rights.
 #
 #   You  should  have  received a  copy  of  the GNU General Public
 #   License along with PodWiki.  Copies  can also be obtained from:
 #
 #     http://www.gnu.org/copyleft/gpl.html
 #
 #   or by writing to:
 #
 #     Free Software Foundation, Inc.
 #     59 Temple Place, Suite 330
 #     Boston, MA 02111-1307
 #     USA
 #
 #   Or contact:
 #
 #    "Thomas Linden" <tom@daemon.de>
 #
 #   Additional Copyrights:
 #
 #

use Storable qw(lock_store lock_retrieve);
use Digest::MD5  qw(md5_hex);

my($data, $password) = @ARGV;

if (! $directory && ! $password) {
  print STDERR "Usage: $0 <data-directory> <password>\n";
  exit;
}

my $ref = {};
if (-e "$data/.podusers") {
  $ref = lock_retrieve("$data/.podusers") or die "Could not open $data/.podusers: $!\n";
}
my %users = %{$ref};

my $gref = {};
if (-e "$data/.podgroups") {
  $gref = lock_retrieve("$data/.podgroups") or die "Could not open $data/.podgroups: $!\n";
}
my %groups = %{$gref};

my $mail     = 'root@localhost';
my $passwd   = md5_hex($password);
$users{root} = "${passwd}:${mail}";

&set_member("root", "root");

lock_store(\%users,  "$data/.podusers")  or die "Could not open $data/.podusers: $!\n";
lock_store(\%groups, "$data/.podgroups") or die "Could not open $data/.podgroups: $!\n";

print "Password for user 'root' has been successfully changed in $data/.podusers.\n";
exit;




sub set_member {
  my($user, $group) = @_;
  my @users = ();
  if (scalar keys %groups > 0) {
    # there are groups
    @users = split /\s*,\s*/, $groups{$group};
    if (! grep {$user eq $_} @users) {
      print "Adding user 'root' to group 'root' in $data/.podgroups.\n";
      $groups{$group} = join ",", (@users, $user);
    }
  }
  else {
    # called by setup(), no groups existing
    print "Adding user 'root' to group 'root' in $data/.podgroups.\n";
    $groups{$group} = $user;
  }
}

==> podwiki-0.8.3.tgz: podwiki-0.8.3/support/pwreset.pl <==
#!/usr/bin/perl

 #
 #   $Id: pwreset.pl,v 1.5 2005/03/24 23:02:47 zarahg Exp $
 #
 #   This  file  is  part of the  PodWiki  web-based authoring tool.
 #
 #   By  accessing  this software,  PodWiki,  you are  duly informed
 #   of and  agree to be  bound  by the  conditions  described below
 #   in this notice:
 #
 #   This software product, PodWiki,  is developed by  Thomas Linden
 #   and   copyrighted  (C) 2003-2005   by  Thomas Linden,  with all
 #   rights reserved.
 #
 #   There is  no charge for  PodWiki software. You can redistribute
 #   it and/or modify it under  the terms of the  GNU General Public
 #   License, which is incorporated by reference herein.
 #
 #   PodWiki is distributed WITHOUT ANY WARRANTY,IMPLIED OR EXPRESS,
 #   OF  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that
 #   the  use of it will not infringe on any third party's intellec-
 #   tual property rights.
 #
 #   You  should  have  received a  copy  of  the GNU General Public
 #   License along with PodWiki.  Copies  can also be obtained from:
 #
 #     http://www.gnu.org/copyleft/gpl.html
 #
 #   or by writing to:
 #
 #     Free Software Foundation, Inc.
 #     59 Temple Place, Suite 330
 #     Boston, MA 02111-1307
 #     USA
 #
 #   Or contact:
 #
 #    "Thomas Linden" <tom@daemon.de>
 #
 #   Additional Copyrights:
 #
 #

use Storable qw(lock_store lock_retrieve);
use Digest::MD5  qw(md5_hex);
use Getopt::Long;

# get commandline options and store them in scalar refs.
use vars qw($user $password $data $help);
eval { Getopt::Long::Configure( qw(no_ignore_case)); }; # might not work with older perl versions

my $success = GetOptions (
			  "user|u=s"    => \$user,
			  "passwd|p:s"  => \$password,
			  "data|d:s"    => \$data,
			  "help|h!"     => \$help
			  );

if (!$success) {
    exit(1);
}

if ($help) {
  &usage;
}

if (! $data && ! $password) {
  &usage
}

if (! $user) {
  $user = "root"; # default
}



my $ref = {};
if (-e "$data/.podusers") {
  $ref = lock_retrieve("$data/.podusers") or die "Could not open $data/.podusers: $!\n";
}
my %users = %{$ref};

my $gref = {};
if (-e "$data/.podgroups") {
  $gref = lock_retrieve("$data/.podgroups") or die "Could not open $data/.podgroups: $!\n";
}
my %groups = %{$gref};

my $mail     = "$user\@localhost";
my $passwd   = md5_hex($password);
$users{$user} = "${passwd}:${mail}";

&set_member("$user", "$user");

lock_store(\%users,  "$data/.podusers")  or die "Could not open $data/.podusers: $!\n";
lock_store(\%groups, "$data/.podgroups") or die "Could not open $data/.podgroups: $!\n";

print "Password for user '$user' has been successfully changed in $data/.podusers.\n";
exit;




sub set_member {
  my($user, $group) = @_;
  my @users = ();
  if (scalar keys %groups > 0) {
    # there are groups
    @users = split /\s*,\s*/, $groups{$group};
    if (! grep {$user eq $_} @users) {
      print "Adding user '$user' to group '$user' in $data/.podgroups.\n";
      $groups{$group} = join ",", (@users, $user);
    }
  }
  else {
    # called by setup(), no groups existing
    print "Adding user '$user' to group '$user' in $data/.podgroups.\n";
    $groups{$group} = $user;
  }
}

sub usage {
  print "$0 [--user <username>] --passwd <password> --data <data-directory>\n";
  exit(1);
}
